[PATCH 7/6] fix some typo in lib/route/act.c

Cong Wang xiyou.wangcong at gmail.com
Fri Dec 6 17:58:38 EST 2013


Signed-off-by: Cong Wang <xiyou.wangcong at gmail.com>
---
 lib/route/act.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/route/act.c b/lib/route/act.c
index 9c00453..ea43210 100644
--- a/lib/route/act.c
+++ b/lib/route/act.c
@@ -216,7 +216,7 @@ int rtnl_act_build_add_request(struct rtnl_act *act, int flags,
  * @arg act		Action to add/update
  * @arg flags		Additional netlink message flags
  *
- * Builds a \c RTM_NEWTFILTER netlink message requesting the addition
+ * Builds a \c RTM_NEWACTION netlink message requesting the addition
  * of a new action and sends the message to the kernel. The
  * configuration of the action is derived from the attributes of
  * the specified traffic class.
@@ -316,7 +316,7 @@ int rtnl_act_change(struct nl_sock *sk, struct rtnl_act *act, int flags)
 int rtnl_act_build_delete_request(struct rtnl_act *act, int flags,
 				  struct nl_msg **result)
 {
-	return act_build(act, RTM_DELTFILTER, flags, result);
+	return act_build(act, RTM_DELACTION, flags, result);
 }
 
 /**
@@ -325,7 +325,7 @@ int rtnl_act_build_delete_request(struct rtnl_act *act, int flags,
  * @arg act		Action to delete
  * @arg flags		Additional netlink message flags
  *
  * Builds a \c RTM_DELTFILTER netlink message requesting the deletion
  * of an action and sends the message to the kernel.
  *
  * The message is constructed out of the following attributes:
@@ -325,7 +325,7 @@ int rtnl_act_build_delete_request(struct rtnl_act *act, int flags,
  * @arg flags		Additional netlink message flags
  *
- * Builds a \c RTM_DELTFILTER netlink message requesting the deletion
+ * Builds a \c RTM_DELACTION netlink message requesting the deletion
  * of an action and sends the message to the kernel.
  *
-- 
1.8.3.1




More information about the libnl mailing list